@@ -1,3 +1,10 @@
+import os
+
+WORKING_DIR = os.getcwd()
+INPUTS = 'inputs'
+OUTPUTS = 'outputs'
+LOGS = 'logs'
+BINS = "bins"
 OPTIMAL = 0
 INFEASIBLE = 1
 ROOT = 0
