@@ -1,11 +1,10 @@
 import datetime
-import os
 import pathlib
 from abc import ABC, abstractmethod
 from time import time
 from typing import List, Optional
 
-from gurobipy import Model, GRB
+from gurobipy.gurobipy import Model, GRB
 from mpi4py.MPI import Intercomm
 from numpy import (
     ndarray,
@@ -820,13 +819,11 @@ class DIPOA(ICardSolver):
         """
         if self.k == 0:
             self.time_stamp = str(datetime.datetime.now()).split('.')[0].replace(' ', '_')
-        folder_name = 'logfiles'
-        target_directory = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
-        pathlib.Path(target_directory + '/' + folder_name).mkdir(exist_ok = True)
 
-        target_file = os.path.join(target_directory, folder_name, f"log_{self.time_stamp}.txt")
-        # if os.path.exists(target_file) and self.k == 0:
-        #     os.remove(target_file)
+        target_directory = WORKING_DIR
+        pathlib.Path(target_directory + '/' + LOGS).mkdir(exist_ok = True)
+
+        target_file = os.path.join(target_directory, LOGS, f"log_{self.time_stamp}.txt")
         with open(target_file, 'a') as writer:
             if not header:
                 writer.write(self.solver_info + '\n')
